==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/nb_NO.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er for tiden ikke tilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "All files" : "Alle filer",
    "Saved" : "Lagret",
    "There was an error saving" : "Det oppstod en feil ved lagring",
    "File could not be found" : "Fant ikke filen",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Favorites" : "Favoritter",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig plass",
    "Uploading..." : "Laster opp...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filopplasting pågår. Forlater du siden nå avbrytes opplastingen.",
    "Actions" : "Handlinger",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Disconnect storage" : "Koble fra lagring",
    "Unshare" : "Avslutt deling",
    "Could not load info for file \"{file}\"" : "Klarte ikke å laste inn informasjon for fil \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "Invalid path" : "Individuell sti",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å omdøpe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkludert %n skjult","inkludert %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ([usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privat lenke: Bare personer som har tilgang til filen/mappen kan bruke den. Bruk dette som en permanent lenge for din egen bruk eller for å lede andre til filer innenfor delinger",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "{newname} already exists" : "{newname} finnes allerede",
    "Upload" : "Last opp",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av stikkordene",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "You created %1$s" : "Du opprettet %1$s",
    "%2$s created %1$s" : "%2$s opprettet %1$s",
    "%1$s was created in a public folder" : "%1$s ble opprettet i en offentlig mappe",
    "You changed %1$s" : "Du endret %1$s",
    "%2$s changed %1$s" : "%2$s endret %1$s",
    "You deleted %1$s" : "Du slettet %1$s",
    "%2$s deleted %1$s" : "%2$s slettet %1$s",
    "You restored %1$s" : "Du gjenopprettet %1$s",
    "%2$s restored %1$s" : "%2$s gjenopprettet %1$s",
    "Changed by %2$s" : "Endret av %2$s",
    "Deleted by %2$s" : "Slettet av %2$s",
    "Restored by %2$s" : "Gjenopprettet av %2$s",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "Save" : "Lagre",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta 5 minutter før endringene trer i kraft.",
    "Missing permissions to edit from here." : "Manglende rettigheter til å redigere herfra.",
    "Settings" : "Innstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Bruk adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">for å få tilgang til WebDAV</a>",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "No favorites" : "Ingen favoritter",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/nb_NO.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er for tiden ikke tilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "All files" : "Alle filer",
    "Saved" : "Lagret",
    "There was an error saving" : "Det oppstod en feil ved lagring",
    "File could not be found" : "Fant ikke filen",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Favorites" : "Favoritter",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig plass",
    "Uploading..." : "Laster opp...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filopplasting pågår. Forlater du siden nå avbrytes opplastingen.",
    "Actions" : "Handlinger",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Disconnect storage" : "Koble fra lagring",
    "Unshare" : "Avslutt deling",
    "Could not load info for file \"{file}\"" : "Klarte ikke å laste inn informasjon for fil \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "Invalid path" : "Individuell sti",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å omdøpe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkludert %n skjult","inkludert %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ([usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privat lenke: Bare personer som har tilgang til filen/mappen kan bruke den. Bruk dette som en permanent lenge for din egen bruk eller for å lede andre til filer innenfor delinger",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "{newname} already exists" : "{newname} finnes allerede",
    "Upload" : "Last opp",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av stikkordene",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "You created %1$s" : "Du opprettet %1$s",
    "%2$s created %1$s" : "%2$s opprettet %1$s",
    "%1$s was created in a public folder" : "%1$s ble opprettet i en offentlig mappe",
    "You changed %1$s" : "Du endret %1$s",
    "%2$s changed %1$s" : "%2$s endret %1$s",
    "You deleted %1$s" : "Du slettet %1$s",
    "%2$s deleted %1$s" : "%2$s slettet %1$s",
    "You restored %1$s" : "Du gjenopprettet %1$s",
    "%2$s restored %1$s" : "%2$s gjenopprettet %1$s",
    "Changed by %2$s" : "Endret av %2$s",
    "Deleted by %2$s" : "Slettet av %2$s",
    "Restored by %2$s" : "Gjenopprettet av %2$s",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "Save" : "Lagre",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta 5 minutter før endringene trer i kraft.",
    "Missing permissions to edit from here." : "Manglende rettigheter til å redigere herfra.",
    "Settings" : "Innstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Bruk adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">for å få tilgang til WebDAV</a>",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "No favorites" : "Ingen favoritter",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Upload timeout for file \"{file}\"" : "Tidsavbrudd for opplasting av fil \"{file}\"",
    "Processing files..." : "Behandler filer...",
    "No entries in this folder match {filter}" : "Ingen oppføringer i denne mappen stemmer med '{filter}'",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong>dine",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Du har ikke tilgangstillatelse til denne filen/mappen - Vennligst be eieren om å dele den med deg. ",
    "Error when assembling chunks, status code {status}" : "Feil ved samling av deler for opplasting, statuskode {status}"
},
"nplurals=2; plural=(n != 1);");
